@@ -1,5 +1,5 @@
 #### prime-sary.rb: Library for sary on PRIME.
-#### $Id: prime-sary.rb,v 1.2 2004/03/25 17:19:51 komatsu Exp $
+#### $Id: prime-sary.rb,v 1.3 2004/05/31 05:27:33 komatsu Exp $
 ####
 #### Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ####     All rights reserved.
@@ -99,7 +99,10 @@ class PrimeSaryMakeIndex
     offset_list.each{|offset|
       ios_index[offset].close()
       builder = Sary::Builder.new(filename_dict, filenames_index[offset])
-      builder.block_sort
+      # FIXME: Sary::Builder::block_sort seems to have a core dump bug.
+      # FIXME: Thanks for the report by Gen Otsuji.
+      # FIXME: (2004-05-30) <komatsu@taiyaki.org>
+      builder.sort()
     }
   end
 
